@@ -69,7 +69,7 @@ typedef SQLSMALLINT SQLRETURN;
 /* TODO - Check how the SQLLEN and SQLULEN types are handled on
  *        64-bit Unix. */
 
-#if defined(__WIN64)
+#if defined(_WIN64)
 typedef Tcl_WideInt SQLLEN;
 typedef Tcl_WideUInt SQLULEN;
 #else
@@ -150,7 +150,8 @@ enum _SQL_DATATYPE {
 /* Diagnostic fields */
 
 enum _SQL_DIAG {
-    SQL_DIAG_SQLSTATE = 4,
+    SQL_DIAG_NUMBER = 2,
+    SQL_DIAG_SQLSTATE = 4
 };
 
 /* Transaction isolation levels */
@@ -268,8 +269,6 @@ MODULE_SCOPE const odbcStubDefs* odbcStubs;
 MODULE_SCOPE BOOL (INSTAPI* SQLConfigDataSourceW)(HWND, WORD, LPCWSTR,
 						  LPCWSTR);
 MODULE_SCOPE BOOL (INSTAPI* SQLConfigDataSource)(HWND, WORD, LPCSTR, LPCSTR);
-MODULE_SCOPE BOOL (INSTAPI* SQLInstallerErrorW)(WORD, DWORD*, LPWSTR, WORD,
-						WORD*);
 MODULE_SCOPE BOOL (INSTAPI* SQLInstallerError)(WORD, DWORD*, LPSTR, WORD,
 					       WORD*);
 
